/*----------------------
    S/W ENTRY POINT
-----------------------*/
/* Entry Point */
ENTRY(_start_core0)

/* SRAM total: 1536KB */

/*----------------------------
    Defaults - Boot header
------------------------------*/
/* Define Bootloader Boot Header area Base Address (boot location 0) */
   BOOTLOADER_BOOT_HEADER_BASE_ADDR = 0x00F98000;
/* Define Bootloader Boot header area Size */
   BOOTLOADER_BOOT_HEADER_SIZE = 0x08;

/* Define Application Boot Header area Base Address (boot location 1) */
   APP_BOOT_HEADER_BASE_ADDR = 0x00F9C000;   
/* Define Application Boot Header area Size */
   APP_BOOT_HEADER_SIZE = 0x08;

/*----------------------------
    Defaults - Flash
------------------------------*/
/* Define Code Flash Base Address */
   FLASH_BASE_ADDR = 0x00FA0000;
/* Define Code Flash Size */
   FLASH_SIZE = 128K;   

/*----------------------------
    Defaults - SRAM
------------------------------*/   
/* Define SRAM Base Adress*/
   SRAM_BASE_ADDR = 0x40000000;
/* Define SRAM Size */
   SRAM_SIZE = 1536K;  
/* Define Core 0 SRAM Allocation */
   C0_SRAM_SIZE = 1000K;

/*-------------------------------------
    Defaults - Local DMEM (TCM & Stack)
---------------------------------------*/
/* Define Processor 0 Local Data SRAM Base Address */
   C0_LOCALDMEM_BASE_ADDR = 0x50800000;
/* Define Local DMEM Allocation */ 
   LOCALDMEM_SIZE = 64K;   
   
/* Define Core 0 Stack Allocation */    
   C0_STACK_SIZE = 4K;

/*-------------------------------------
    Defaults - Heap
---------------------------------------*/
/* Define Core 0 Heap Allocation */    
   C0_HEAP_SIZE =  536K;

  
/*----------------------
   MEMORY PARTITIONS
-----------------------*/
MEMORY
{

   /* Boot area for core 0 */
   flash_rchw : org = BOOTLOADER_BOOT_HEADER_BASE_ADDR,   len = BOOTLOADER_BOOT_HEADER_SIZE

   /* Flash memory areas for each core */
   c0_flash : org = FLASH_BASE_ADDR,     			      len = FLASH_SIZE
       
   /* SRAM areas for each core */
   c0_sram  : org = SRAM_BASE_ADDR,   					  len = C0_SRAM_SIZE
   
   /* Tightly coupled memories */
   c0_TCM : org = C0_LOCALDMEM_BASE_ADDR,  				  len = LOCALDMEM_SIZE - C0_STACK_SIZE
   
   /* Stack */
   c0_stack : org = ORIGIN(c0_TCM) + LENGTH(c0_TCM),      len = C0_STACK_SIZE
   
   /* Heap*/
   c0_heap : org = ORIGIN(c0_sram) + LENGTH(c0_sram),     len = C0_HEAP_SIZE
   
   /* Shared SRAM area */ 
   /*all_sram  : org = ORIGIN(c0_heap) + LENGTH(c0_heap),   len = SRAM_SIZE - C0_SRAM_SIZE - C0_HEAP_SIZE*/
         
   
}

	/*----------------------
	  SYMBOL DEFINITION 
	-----------------------*/

	/* Applicaton Bootflash parameters*/
	__APP_BOOT_HEADER_BASE_ADDR = APP_BOOT_HEADER_BASE_ADDR;
	__APP_BOOT_HEADER_END_ADDR = APP_BOOT_HEADER_BASE_ADDR + APP_BOOT_HEADER_SIZE;

	/* Bootloader Bootflash parameters*/
	__BOOTLOADER_BOOT_HEADER_BASE_ADDR = BOOTLOADER_BOOT_HEADER_BASE_ADDR;
	__BOOTLOADER_BOOT_HEADER_END_ADDR = BOOTLOADER_BOOT_HEADER_BASE_ADDR + BOOTLOADER_BOOT_HEADER_SIZE;

	/* Bootloader code parameter*/
	__BOOTLOADER_CODE_BASE_ADDR = FLASH_BASE_ADDR;
	__BOOTLOADER_CODE_END_ADDR = FLASH_BASE_ADDR + FLASH_SIZE;
	/* Boot header area base address (boot location 0) */
	
	__BOOTFLASH_BASE_ADDR = ORIGIN(flash_rchw);
	__BOOTFLASH_SIZE = LENGTH(flash_rchw);
	
	/* Core 0 flash and SRAM addresses and sizes */
	
	/* Core 0 Flash Allocation */
	__C0_FLASH_SIZE = LENGTH(c0_flash); 
	/* Core 0 Flash Base Address */ 
	__C0_FLASH_BASE_ADDR =  ORIGIN(c0_flash);
	/* Core 0 SRAM Allocation */ 
	__C0_SRAM_SIZE = LENGTH(c0_sram);
	/* Core 0 SRAM Base Address */
	__C0_SRAM_BASE_ADDR = ORIGIN(c0_sram);
	/* Core 0 Local Data SRAM Allocation */  
	__C0_LOCAL_DMEM_SIZE =  LENGTH(c0_TCM) + LENGTH(c0_stack);
	/* Core 0 Local Data SRAM Base Address */
	__C0_LOCAL_DMEM_BASE_ADDR = ORIGIN(c0_TCM);
	/* Core 0 Stack and heap size */
	__C0_STACK_SIZE = C0_STACK_SIZE;
	__C0_HEAP_SIZE = C0_HEAP_SIZE;
	

	/* Define shared SRAM Allocation */
	/*__ALL_SRAM_SIZE =  LENGTH(all_sram);*/
	/* Define shared SRAM Base Address */
	/*__ALL_SRAM_BASE_ADDR = ORIGIN(all_sram); */
